# Security Policy

## Overview

Security scans are completed on every push using CodeQL.  This workflow was implemented for versions >= 1.0.0

## Reporting a Vulnerability

To report a vulnerability, please open an issue in the repository or e-mail the owner directly at
<brandon.sexton.1@outlook.com>
